# omz_ignore_theme

Add current RANDOM_THEME from oh-my-zsh to the .zshrc file to the ZSH_RANDOM_IGNORE_THEME section. Use via zsh alias via source:

`alias it="python3 omz_theme_ignore/main.py $RANDOM_THEME"`

or via package after installing via pip:

`python3 -m pip install omz_theme_ignore`

`alias it="omz_theme_ignore $RANDOM_THEME"`
